<?php 

$lang['title'] = 'New module creation';

$lang['Created'] = 'Module %s created';
$lang['Empty module name'] = 'Module name can\'t be empty';
$lang['Module already exists'] = 'Module %s exist';
$lang['Other error'] = 'Module creation fail';

$lang['Enter'] = 'Enter';
$lang['module folder'] = 'Module catalog';
$lang['module name'] = 'Module name';
$lang['create module'] = 'Create';
