<?php 

$lang['title'] = 'Створення нового модулю';

$lang['Created'] = 'Модуль %s створений';
$lang['Empty module name'] = 'Назва модуля не може бути пуста';
$lang['Module already exists'] = 'Модуль %s існує';
$lang['Other error'] = 'Помилка створення модулю';

$lang['Enter'] = 'Введіть';
$lang['module folder'] = 'Каталог модуля';
$lang['module name'] = 'Назва модуля';
$lang['create module'] = 'Створити';
